@@ -1,20 +1,18 @@
-import posixpath
-
 from django.http import HttpResponse
 
 from django.contrib import admin
 
 from adminfiles.models import FileUpload
-from adminfiles.settings import ADMINFILES_MEDIA_URL, JQUERY_URL
+from adminfiles.settings import JQUERY_URL
 from adminfiles.listeners import register_listeners
 
 class FileUploadAdmin(admin.ModelAdmin):
-    list_display = ('title', 'upload_date', 'upload', 'mime_type')
+    list_display = ['title', 'description', 'upload_date', 'upload', 'mime_type']
+    list_editable = ['description']
     prepopulated_fields = {'slug': ('title',)}
 # uncomment for snipshot photo editing feature
 #    class Media:
-#        js = (JQUERY_URL, posixpath.join(ADMINFILES_MEDIA_URL,
-#                                         'photo-edit.js'))
+#        js = (JQUERY_URL, 'photo-edit.js')
     def response_change(self, request, obj):
         if request.POST.has_key("_popup"):
             return HttpResponse('<script type="text/javascript">'
@@ -40,15 +38,15 @@ class FileUploadAdmin(admin.ModelAdmin):
         return super(FileUploadAdmin, self).response_add(request,
                                                          *args,
                                                          **kwargs)
-            
-        
+
+
 class FilePickerAdmin(admin.ModelAdmin):
     adminfiles_fields = []
 
     def __init__(self, *args, **kwargs):
         super(FilePickerAdmin, self).__init__(*args, **kwargs)
         register_listeners(self.model, self.adminfiles_fields)
-    
+
     def formfield_for_dbfield(self, db_field, **kwargs):
         field = super(FilePickerAdmin, self).formfield_for_dbfield(
             db_field, **kwargs)
@@ -60,6 +58,6 @@ class FilePickerAdmin(admin.ModelAdmin):
         return field
 
     class Media:
-        js = [JQUERY_URL, posixpath.join(ADMINFILES_MEDIA_URL, 'adminfiles/model.js')]
+        js = [JQUERY_URL, 'adminfiles/model.js']
 
 admin.site.register(FileUpload, FileUploadAdmin)
